@@ -16,6 +16,7 @@ from .middleware import (
     http_request_context,
     http_request_middleware_func,
 )
+from .tracer import add_traces_to_fastapi
 
 
 class InterceptHandler(logging.Handler):
@@ -67,7 +68,7 @@ def stackdriver_sink(message, project):
 
     trace = cloud_trace_context.get()
     if trace is not None:
-        split_header = trace.split("/", 1) if trace else None
+        split_header = trace.split("/", 1)
 
         trace_id = f"projects/{project}/traces/{split_header[0]}"
 
@@ -82,12 +83,16 @@ def stackdriver_sink(message, project):
     print(serialized, file=sys.stderr)
 
 
-def setup_logging_fastapi_gcp(app: FastAPI, GCP_PROJECT="databutton"):
+def setup_logging_fastapi_gcp(
+    app: FastAPI, *, enable_tracing=True, GCP_PROJECT="databutton"
+):
     """
     Sets up logging and tracing for FastAPI based projects.
     """
     app.add_middleware(BaseHTTPMiddleware, dispatch=http_request_middleware_func)
     app.add_middleware(CorrelationIdMiddleware)
+    if enable_tracing:
+        add_traces_to_fastapi(app)
 
     loggers = (
         logging.getLogger(name)
